summaryrefslogtreecommitdiffstats
path: root/chrome/browser/gtk/extension_view_gtk.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/gtk/extension_view_gtk.h')
-rw-r--r--chrome/browser/gtk/extension_view_gtk.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/browser/gtk/extension_view_gtk.h b/chrome/browser/gtk/extension_view_gtk.h
index 6f67f53..16b7892 100644
--- a/chrome/browser/gtk/extension_view_gtk.h
+++ b/chrome/browser/gtk/extension_view_gtk.h
@@ -7,6 +7,7 @@
#include "app/gfx/native_widget_types.h"
#include "base/basictypes.h"
+#include "base/gfx/size.h"
#include "third_party/skia/include/core/SkBitmap.h"
class Browser;
@@ -29,9 +30,9 @@ class ExtensionViewGtk {
void SetBackground(const SkBitmap& background);
// Method for the ExtensionHost to notify us about the correct width for
// extension contents.
- void UpdatePreferredWidth(int pref_width);
+ void UpdatePreferredSize(const gfx::Size& new_size);
// Method for the ExtensionHost to notify us when the RenderViewHost has a
// connection.
@@ -29,9 +30,9 @@ class ExtensionViewGtk {
void SetBackground(const SkBitmap& background);
- // Method for the ExtensionHost to notify us about the correct width for
+ // Method for the ExtensionHost to notify us about the correct size for
// extension contents.